import { Signature } from './base';
import { SHA512 } from './SHA512';
/**
 * Curve25519 class
 */
export declare class Curve25519 {
    gf0: Float64Array;
    gf1: Float64Array;
    D: Float64Array;
    D2: Float64Array;
    I: Float64Array;
    _9: Uint8Array;
    _121665: Float64Array;
    /**
     * Curve25519 ctor
     */
    constructor();
    gf(init?: Array<number>): Float64Array;
    verify_32(x: Uint8Array, xi: number, y: Uint8Array, yi: number): number;
    private A(o, a, b);
    private Z(o, a, b);
    M(o: Float64Array, a: Float64Array, b: Float64Array): void;
    private S(o, a);
    add(p: any, q: any): void;
    set25519(r: any, a: any): void;
    private car25519(o);
    private sel25519(p, q, b);
    inv25519(o: Float64Array, i: Float64Array): void;
    private neq25519(a, b);
    par25519(a: Float64Array): number;
    private pow2523(o, i);
    cswap(p: Array<Float64Array>, q: Array<Float64Array>, b: number): void;
    pack25519(o: Uint8Array, n: Float64Array): void;
    private unpack25519(o, n);
    unpackneg(r: any, p: any): number;
    /**
     * Internal scalar mult function
     * @param q Result
     * @param s Secret key
     * @param p Public key
     */
    private crypto_scalarmult(q, s, p);
    /**
     * Generate the common key as the produkt of sk1 * pk2
     * @param {Uint8Array} sk A 32 byte secret key of pair 1
     * @param {Uint8Array} pk A 32 byte public key of pair 2
     * @return {Uint8Array} sk * pk
     */
    scalarMult(sk: Uint8Array, pk: Uint8Array): Uint8Array;
    /**
     * Generate a curve 25519 keypair
     * @param {Uint8Array} seed A 32 byte cryptographic secure random array. This is basically the secret key
     * @param {Object} Returns sk (Secret key) and pk (Public key) as 32 byte typed arrays
     */
    generateKeys(seed: Uint8Array): {
        sk: Uint8Array;
        pk: Uint8Array;
    };
    /**
     * Performs a quick selftest
     * @param {Boolean} Returns true if selftest passed
     */
    selftest(): boolean;
}
/**
 * Ed25519 class
 */
export declare class Ed25519 implements Signature {
    curve: Curve25519;
    sha512: SHA512;
    X: Float64Array;
    Y: Float64Array;
    /**
     * Ed25519 ctor
     */
    constructor();
    private pack(r, p);
    private modL(r, x);
    private reduce(r);
    private scalarmult(p, q, s);
    private scalarbase(p, s);
    /**
     * Generate an ed25519 keypair
     * Some implementations represent the secret key as a combination of sk and pk. mipher just uses the sk itself.
     * @param {Uint8Array} seed A 32 byte cryptographic secure random array. This is basically the secret key
     * @param {Object} Returns sk (Secret key) and pk (Public key) as 32 byte typed arrays
     */
    generateKeys(seed: Uint8Array): {
        sk: Uint8Array;
        pk: Uint8Array;
    };
    /**
     * Generate a message signature
     * @param {Uint8Array} msg Message to be signed as byte array
     * @param {Uint8Array} sk Secret key as 32 byte array
     * @param {Uint8Array} pk Public key as 32 byte array
     * @param {Uint8Array} Returns the signature as 64 byte typed array
     */
    sign(msg: Uint8Array, sk: Uint8Array, pk: Uint8Array): Uint8Array;
    /**
     * Verify a message signature
     * @param {Uint8Array} msg Message to be signed as byte array
     * @param {Uint8Array} pk Public key as 32 byte array
     * @param {Uint8Array} sig Signature as 64 byte array
     * @param {Boolean} Returns true if signature is valid
     */
    verify(msg: Uint8Array, pk: Uint8Array, sig: Uint8Array): boolean;
    /**
     * Performs a quick selftest
     * @param {Boolean} Returns true if selftest passed
     */
    selftest(): boolean;
}
